function results = alpha1vs2(data, plan, infoString)
% Make several test runs for the mean vs. spatmed comparison.
% This is applicable to any training data.
%
% TODO: In fact, with the new analysis code this need not compute and 
%       store the accuracy measures. Instead, it suffices that this saves
%       all information required to exactly reproduce the final MLP after
%       training, and the data set that was used in training. Then it is
%       possible to re-evaluate outputs afterwards, and compute whatever 
%       measures, or even continue training. But time runs short;
%       expect better quality code with our next paper...
%
% This will do a lot of trial runs; a pythonese pseudocode:
%
%   for nruns times:
%     init a random MLP
%     Make copies of the MLP to be trained by L_2^1 and L_2^2 formulation.
%
%     for rdirty in planDirty:
%       obfuscate rdirty (ratio) of training labels randomly
%
%       for regc in planRegc:
%         re-init MLP (to the original random weights & decay coeff = regc)
%
%         for niters in planIters:
%           From current state, train L_2^1 and L_2^2 until stop or niters iterations.
%           Compute quality measures, and store:
%             - train set accuracy
%             - test set accuracy
%             - train&test set confusion matrices
%             - mean of train set error vectors
%             - mean of test set error vectors
%
% Return a structure containing the above, it will be a hierarchical
% structure:
%
% Actual results:
%   results.resOfCase{idirty}{irun}{iregc}{ibreakpoint}{alpha} = res;
% To help you remember what you asked us to do:
%   results.plan = plan;
%   results.redoable
%

tic();  startTime = toc();

% Just in case you need to redo exactly the same run 
%results.redoable.defaultRandStream = RandStream.getDefaultStream; %(Matlab 7.7 stream - I don't know how to save this...)
results.redoable.randstate = rand('state');
results.redoable.randnstate = randn('state');

% Local copies of nperms, nruns, planIters, planDirty, planRegc:
nruns     = plan.nruns; 
planIters = plan.planIters;
planDirty = plan.planDirty;
planRegc  = plan.planRegc;

dirtifyInputs = strcmp(plan.dirtify,'inputs');

prototypes    = data.prototypes;

nsessions = nruns*numel(planDirty)*numel(planRegc)*2*numel(planIters); % breakpoints with *numel(planIters)
fprintf(1, '*****\nStarting %d training sessions. May take a while.. \n', nsessions);

%%  Create dirtied labels
% (They'll be taken all the time from the beginning of the same wrong
% labeling we create here)

% Locate the labels that we want to confuse
indsOfLabelsToDestroy=[];
for dc = plan.dirtifyClasses
    indsOfLabelsToDestroy = [indsOfLabelsToDestroy find(data.trainLabelInts==dc)];
end
indsOfLabelsToDestroy = sort(indsOfLabelsToDestroy);
nlabelsToDestroy = numel(indsOfLabelsToDestroy); % Corresponds to 100% 

% Prepare the wrong labels
randomWrongClassInts = randomlyChangeNumbers(data.trainLabelInts(indsOfLabelsToDestroy));



%% ---- Actual loops begin here ----

%% Random initializations
% Initializations are the outer loop in order to isolate the effect of
% the choises made in the inner loops when initial weights are fixed.
for irun = 1:nruns
    % Pick random initial weights, and optimize from there:
    initNet{1} = simple_mlp_create([size(data.trainVectors,1) plan.nnHiddenArch size(prototypes,1)]);
    initNet{2} = initNet{1};
    
    initNet{1}.alpha = 1;   % OK; should have had "alphaPlan" but let's do it thus now.
    initNet{2}.alpha = 2;
    
    
    for idirty = 1:numel(planDirty)
        elapsedTime = toc() - startTime;   % toc(tStart) N/A in Octave
        statusStr = sprintf('--- At init %d/%d dirty %d/%d. time is %.2f seconds', ...
            irun, nruns, idirty, numel(planDirty), elapsedTime);
        disp(statusStr);
        
        %% Simulate wrong labels in training data; to see how it
        % affects either the mean or spatial median training..
        % We need to start with original, unnoisy data for each dirtying round
        inputs = data.trainVectors;
        targetInts = data.trainLabelInts;
        rdirty = planDirty(idirty);
        %nwrong = floor(rdirty*size(inputs,2));
        nwrong = floor(rdirty*nlabelsToDestroy);
        
        if dirtifyInputs  % (completely, into plain uniform noise)
            error('not relevant to our study anymore..');
            inputs(:,1:nwrong) = min(min(inputs)) + rand(size(inputs,1),nwrong) * max(max(inputs))-min(min(inputs));
        else % (dirtify targets by giving the outright wrong labels)
            fprintf(1, 'Simulate %d wrong labels out of %d\n', nwrong, ...
                    nlabelsToDestroy);
            targetInts(:,indsOfLabelsToDestroy(1:nwrong)) = ...
                randomWrongClassInts(1:nwrong);
        end
        target = prototypes(:,targetInts);   % Class coding takes place here
        
        trainLabelsPresented{idirty} = targetInts; % Store for later reconstruction
        
        
        %% Scale inputs of training and testing
        % Scale input to [-1,1]:
        [inputs, traA, traB] = scaleCols(inputs,[-1 1]);
        % Use the same scaling for the "unknown" test data:
        testx = scaleCols(data.testVectors,traA,traB);
        trueOut = prototypes(:,data.testLabelInts);
        
    
        %% Restarts using different regularization parameter
        for iregc = 1:numel(planRegc)
            regc = planRegc(iregc);
            net{1} = initNet{1};    % use the outer loop inits
            net{2} = initNet{2};
            
            net{1}.regc = regc;
            net{2}.regc = regc;
            
            %% Perform a single test run, using given restart breakpoints
            for ibreakpoint = 1:numel(planIters)
                niters = planIters(ibreakpoint);
                
                uFunc = @simple_mlp_evalMSErVecWrap;   %Could be parameter..
                
                % Run for both formulations of cost (1=spatmed 2=mean)
                for alpha = 1:2
                    nowDoing = sprintf('%s dirty %d/%d  run %d/%d  regc %d/%d  breakp %d/%d (maxEpoch %d/%d) alpha %d/%d',...
                        infoString, ...
                        idirty, numel(planDirty), irun, nruns, iregc, numel(planRegc), ...
                        ibreakpoint, numel(planIters), sum(planIters(1:ibreakpoint),2),sum(planIters,2), alpha, 2);
                    disp(nowDoing);
                    
                    % Train the network further from current weights.
                    uPar.net = net{alpha};
                    uPar.inputs = inputs;
                    uPar.targets = target;
                    
                    % You may opt for "no training for the first recorded
                    % accuracy" - just have zero as planIters(0)
                    if niters > 0
                      x = simple_mlp_cell2vec(net{alpha}.W);
                      x = simple_mlp_optimWrapSolvOpt(x, uFunc, uPar, ...
                          1, niters, 0, 1e-6);
                      net{alpha}.W = simple_mlp_vec2cell(x, net{alpha}.nneur);
                    end
                    
                    % Evaluate and store accuracy measures.
                    
                    res = alpha1vs2_computeAccuracies(...
                        net{alpha}, inputs, target, testx, trueOut, prototypes);
                    
                    % I store the MLP, to facilitate later
                    % reconstruction of the current situation.
                    res.currentMLP = net{alpha};
                    %res.targetIntsWithCorruption = targetInts; % not here!
                    
                    resOfCase{idirty}{irun}{iregc}{ibreakpoint}{alpha} = res;

                end
            end
        end
    end
    
    % Just in case you wanna quit early; we store intermediate
    % results..
    fname = fullfile(alpha1vs2_dirsetup('tempdir'),'Alpha1vs2_resOfCaseTmp.mat');
%    save('-v6',fname,'resOfCase')
    save(fname,'resOfCase')
    togo = nruns-irun;
    wwwStr = sprintf('Finished %d/%d. %d to go!', irun, nruns, togo);
    if ~exist('OCTAVE_VERSION') % then I'm likely running Matlab
                                % overnight on university PC and 
				                % can write a log note to self:
        if ispc
          dlmwrite('W:\kool_matlabstatus.txt', [datestr(now) ': ' wwwStr], ...
                 '-append', 'delimiter', '');
        else
          dlmwrite('/home3/363/nieminen/html/charra_matlabstatus.txt', ...
              [datestr(now) ': ' wwwStr], '-append', 'delimiter', '');
        end
          
    end
end

elapsedTime = toc() - startTime;

%Phew; we're done. Return results.
results.resOfCase = resOfCase;
results.trainLabelsPresented = trainLabelsPresented;
results.plan = plan;
results.execTime = elapsedTime;
