function res = alpha1vs2_computeAccuracies(tmpnet, input, target, testx, trueOut, prototypes)
% Compute cost functions and accuracies for the network and data given.
%
% TODO: We should also make post-run analysis of optimality conditions etc. 

tmpnet1 = tmpnet;
tmpnet1.regc=0; % for differentiating cost and penalty.
tmpnet1.alpha=1; % to get L_2^1 error without penalty
tmpnet2 = tmpnet1;
tmpnet2.alpha=2; % to get L_2^2 error without penalty

% Cost functions with and without regularization penalties.
% With:
trainCostF = simple_mlp_evalMSEr(tmpnet, input, target);
testCostF = simple_mlp_evalMSEr(tmpnet, testx, trueOut);

% Without: (both L_2^1 and L_2^2 computed here, regardless of which was
% used in training)
trainCostFNoPen1 = simple_mlp_evalMSEr(tmpnet1, input, target);
trainCostFNoPen2 = simple_mlp_evalMSEr(tmpnet2, input, target);
testCostFNoPen1 = simple_mlp_evalMSEr(tmpnet1, testx, trueOut);
testCostFNoPen2 = simple_mlp_evalMSEr(tmpnet2, testx, trueOut);

% Just copy to the result structure
res.trainCostF = trainCostF;
res.testCostF = testCostF ;

res.trainCostFNoPen1 = trainCostFNoPen1;
res.trainCostFNoPen2 = trainCostFNoPen2;
res.testCostFNoPen1 = testCostFNoPen1;
res.testCostFNoPen2 = testCostFNoPen2;

% Validity measures against ground truth.
trainOut = simple_mlp_evalMSEr(tmpnet, input, 'feed');
testOut = simple_mlp_evalMSEr(tmpnet, testx, 'feed');

% We interpret the MLP output as the class whose prototype is closest.
% The result is the same as for the interpretation scheme presented in
% our paper, but by using closest prototype, we could experiment with
% other kinds of prototypes, like ones on 2d circle rim, vertices of a
% hypercube, etc.
[dummy, trainTrueClasses] = classifToClosest(target, prototypes);
[dummy, trainClasses] = classifToClosest(trainOut, prototypes);
[dummy, testClasses] = classifToClosest(testOut, prototypes);
[dummy, trueClasses] = classifToClosest(trueOut, prototypes);

trainConfMat = confusionMatrixFromIndices(trainClasses, trainTrueClasses);
testConfMat = confusionMatrixFromIndices(testClasses, trueClasses);

trainAcc = confusionMatrix_getRates(trainConfMat);
testAcc = confusionMatrix_getRates(testConfMat);

res.trainConfMat = trainConfMat;
res.testConfMat = testConfMat;
res.trainAcc = trainAcc;
res.testAcc = testAcc;
