function processedResults = alpha1vs2_resToMatrix(results)
% This will process our results into a more readable form..
% TODO: Rename the function to something like cell2mat or so...?
%
% The original results were returned as a cell array thus:
%
% results{idataset}.resOfCase{idirty}{irun}{iregc}{ibreakpoint}{alpha}.trainAcc etc
%
% Here we take averages over the initializations and dirty ratios to see an 
% "approximate overall performance". 
%
% We return arrays usable for computing averages. For example:
%
%   processedResults.trainAcc(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.trainAcc;
%   processedResults.testAcc(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.testAcc;
%
%

% nperms shall be the number of different datasets/permutations:
nperms = length(results);    % ... was .plan.nperms

% Iterate over datasets:
for iperm = 1:nperms
    % Local copies of nperms, nruns, planIters, planDirty, planRegc:
    nruns = results{iperm}.plan.nruns;
    planIters = results{iperm}.plan.planIters;
    planDirty = results{iperm}.plan.planDirty;
    planRegc = results{iperm}.plan.planRegc;
    
    for idirty = 1:numel(planDirty)
        rdirty = planDirty(idirty);
        for irun = 1:nruns
            for iregc = 1:numel(planRegc)
                for ibreakpoint = 1:numel(planIters)
                    nitersSum = sum(planIters(1:ibreakpoint));
                    for alpha=1:2
                        % Unload results from the cell array to matrices
                        res = results{iperm}.resOfCase{idirty}{irun}{iregc}{ibreakpoint}{alpha};
                        
                        resTabular.trainCostF(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.trainCostF;
                        resTabular.testCostF(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.testCostF;
                        resTabular.trainCostFNoPen1(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.trainCostFNoPen1;
                        resTabular.trainCostFNoPen2(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.trainCostFNoPen2;
                        resTabular.testCostFNoPen1(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.testCostFNoPen1;
                        resTabular.testCostFNoPen2(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.testCostFNoPen2;
                        
                        % Extract the value of the regularization penalty term
                        if alpha==1
                          resTabular.trainPenalty(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.trainCostF - res.trainCostFNoPen1;
                          resTabular.testPenalty(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.testCostF - res.testCostFNoPen1;
                        else
                          resTabular.trainPenalty(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.trainCostF - res.trainCostFNoPen2;
                          resTabular.testPenalty(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.testCostF - res.testCostFNoPen2;
                        end
                        
                        resTabular.trainAcc(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.trainAcc;
                        resTabular.testAcc(iperm,idirty,irun,iregc,ibreakpoint,alpha) = res.testAcc;
                    end
                end
            end
        end
    end
end

%Phew.. Then it is in a multidim tabular form that we can index and
%plot, and sort, and all that kind of stuff..

processedResults = resTabular;
processedResults.firstPlan = results{1}.plan;  % Store the first plan (hack, sufficient for today's purpose)
processedResults.nperms = nperms;  % how many different datasets (or permutations) were used
