% A "driver" for MLP mean and spatmed training.
% Any data (preloaded)
function results = alpha1vs2_runOneCase(...
    plan, rawFeatures, rawLabelInts, resultDumpFilename)

% We use "plan" to also remember the random states, for repeatability.
% To repeat, issue rand('state',someOldPlan.randState) before calling this
% function.
plan.randState = rand('state');
plan.randnState = randn('state');

%% We create many scenarios by random permutations of data.
% We split the data differently for training (rTrainSet *100%) and testing
% ((1-rTrainSet) *100%).
for iperm = 1:plan.nperms
    [trainV, trainLI, testV, testLI, trainInd, testInd] = ...
        permuteAndSplitData(rawFeatures, rawLabelInts, plan.rTrainSet);
    data.trainVectors   = trainV;
    data.trainLabelInts = trainLI;
    data.testVectors    = testV;
    data.testLabelInts  = testLI;
    data.prototypes     = plan.prototypes;
    
    %% Run the experiment for this permutation, and store results
    resOfCase = alpha1vs2(data, plan, sprintf('Permutation %d/%d', iperm, plan.nperms));
    resOfCase.trainInd = trainInd; % I store the indices, just in case...
    resOfCase.testInd = testInd;

    results{iperm}=resOfCase;
    %% Save at the end of each permutation (can examine partial results)
    save(resultDumpFilename,'results')
end    
