function st = alpha1vs2_tabularize(processedResults, param, param2)
% Prints some indicative numbers about the processed results of the 
% mean vs. spatmed training runs;ASSUMES ALL PLANS WERE THE SAME!

% processedResults - results of one dataset/permutation thereof,
%                    processed into tabular form
%
% It is, for example: 
%    processedResults.testAcc(iperm,idirty,irun,iregc,ibreakpoint,alpha)

plan = processedResults.firstPlan;

trainAcc = processedResults.trainAcc;
testAcc = processedResults.testAcc;
trainCostF = processedResults.trainCostF;

iregc = size(testAcc,4); % Use the last mentioned regc only.

%% I ended up with some extended parameters; process them here.
if nargin == 1
    examineOnlyBestCost = true;    % As if we did multistart (default)
    ibreakpoint = size(testAcc,5); % Use the last breakpoint only.
else
    % 2nd parameter 'onlyBest' / 'allInits'
    if strcmp(param,'onlyBest'), examineOnlyBestCost = true;
    elseif strcmp(param,'allInits'), examineOnlyBestCost = false;
    else error('select either "onlyBest" or "allInits" as 2nd param.');
    end
    
    % 3rd parameter, the breakpoint to study
    if nargin == 2
        ibreakpoint = size(testAcc,5); % Use the last breakpoint only.
    else
        ibreakpoint = param2;
    end
end


st = '';
%% The most interesting thing: Test accuracies for different amounts of mislabeling.
for idirty=1:size(testAcc,2)
    % single out this dirtification:
    nperm  = size(testAcc,1);
    nruns  = size(testAcc,3);
    
    teaME  = reshape(testAcc(:,idirty,:,iregc,ibreakpoint,1), nperm, nruns);
    teaMSE = reshape(testAcc(:,idirty,:,iregc,ibreakpoint,2), nperm, nruns);
    trcME  = reshape(trainCostF(:,idirty,:,iregc,ibreakpoint,1), nperm, nruns);
    trcMSE = reshape(trainCostF(:,idirty,:,iregc,ibreakpoint,2), nperm, nruns);
    
    % Make selection of the best init (with respect to :
    [dummy, iBestInitME] = min(trcME, [], 2);
    [dummy, iBestInitMSE] = min(trcMSE, [], 2);
    
    % Select the index set over which to evaluate:
    if examineOnlyBestCost
        % Mean over permutations (not inits, as we selected only the 'best' one):
        indsME  = sub2ind([nperm nruns], 1:nperm, iBestInitME');
        indsMSE = sub2ind([nperm nruns], 1:nperm, iBestInitMSE');
    else
        % Mean over all runs (both inits and permutations):
        indsME  = 1:(nperm*nruns);
        indsMSE = 1:(nperm*nruns);
    end
    
    % Put it all in a row vector.
    accME  = reshape(teaME(indsME),1,numel(teaME(indsME)));
    accMSE = reshape(teaMSE(indsMSE),1,numel(teaME(indsMSE)));

    % Then compute mean and standard deviation over the selected package:
    meanAccuracyME  = mean(accME);
    meanAccuracyMSE  = mean(accMSE);
    meanAccuracyStdME = std(accME);
    meanAccuracyStdMSE = std(accMSE);


    % Print in the format I want to copy-paste into my LaTeX publication:
    st = [st ...
    sprintf('          &            &  $%2.0f$\\%% & $%4.1f$\\%% & $%4.1f$\\%% \\\\\n', ...
        100*plan.planDirty(idirty), ...
        100*meanAccuracyMSE, 100*meanAccuracyME )];
end
