function alpha1vs2_visThreeClasses(data,netInit1, netInit2)
% Make illustration of the end result of one particular run.
%
% data.trainV  - train vectors
% data.trainTi - train labels (integers)
% data.trainWi - indices of wrong training labels
%
% data.testV   - test vectors
% data.testLi  - test labels (integers)
% data.prototypes - class encoding vectors
%
% data.planIter - plan of iterations, as in our test cases
%
% netInit1     - Initial network for alpha=1
% netInit2     - Initial network for alpha=2


%% Encode targets. 
prototypes = data.prototypes;

% apply prototypes:
inputs  = data.trainV;
target  = prototypes(:,data.trainTi);

testx   = data.testV;
trueOut = prototypes(:,data.testLi);

indicesOfWrongEntries = data.trainWi;


%% Make the demo visualization

% Initialize figures.
figOriginal{1} = figure; %fig or axes?
figOverlay{1} = figure;
figOriginal{2} = figure; %fig or axes?
figOverlay{2} = figure;

net{1} = netInit1; 
net{2} = netInit2; 


for alpha = 1:2
    % Evaluate and print accuracy measures.
    trainOut = simple_mlp_evalMSEr(net{alpha}, inputs, 'feed');
    testOut = simple_mlp_evalMSEr(net{alpha}, testx, 'feed');
    
    res = alpha1vs2_computeAccuracies(...
        net{alpha}, inputs, target, testx, trueOut, prototypes);  % TODO: better output
    
    fprintf(1,'Accuracy for alpha=%d train %.2f test %.2f\n',alpha,res.trainAcc, ...
        res.testAcc);
    
    figure(figOriginal{alpha}); clf;
    demo_plot3binaryClasses('separate',prototypes,trainOut, target, testOut, trueOut, indicesOfWrongEntries);
    set(gca, 'CameraPosition', [1 1 1], 'CameraTarget', [0 0 0], 'CameraUpVector', [0 0 1]);
    
    figure(figOverlay{alpha}); clf;
    demo_plot3binaryClasses('overlay',prototypes,trainOut, target, testOut, trueOut, indicesOfWrongEntries);
    set(gca, 'CameraPosition', [1 1 1], 'CameraTarget', [0 0 0], 'CameraUpVector', [0 0 1]);
end
