% Visualizations for our WCCI 2010 paper.
%
% This script plots the network action on one individual experiment,
% selected for good visual impact from among our Iris results.
%
% There will be 8 figures plotted, and we included the 3rd, 4th, 6th and
% 8th as illustrations in our conference paper.
%
% The figures will need to be hand-tuned to achieve balanced scaling and
% location of the legend box.

%clear all;
%% Load original data (once.. can comment it out afterwards):
dataFileName = fullfile(riscpros_setup('ucidir'),'iris','iris_numerical.dat');
[rawFeatures, rawLabelInts] = loadLabeledData(dataFileName, 150, 4+1, 5);
nclasses = max(rawLabelInts);

%% Load results (once.. can comment it out afterwards):
%load c:\MyTemp\nieminen\Matlab_res_iris_s20100204T235136.mat

% After comparing alternatives, we choose the following permutation 
% and restart based on visual impact:
iperm = 7; irun = 18;

% In these, we can see what we believe to be the characteristic difference
% of behaviour between alpha=1 and alpha=2, and the plot scales become
% visually nice.

%% Visualization 1: clean data
idirty = 1;  % Clean data
ibreakp = 2; % Beginning of training (after only 100 iterations)
alpha1vs2_recreateAndVisualize(rawFeatures,rawLabelInts,results,iperm,idirty,irun,ibreakp);

%% Visualization 2: 20% class noise
idirty = 3;  % The 20% noise is at index 3.
ibreakp = length(results{iperm}.resOfCase{1}{1}{1});  % After full training
alpha1vs2_recreateAndVisualize(rawFeatures,rawLabelInts,results,iperm,idirty,irun,ibreakp);
