function demo_plot3binaryClasses(kind, prototypes, ...
    trainOut, trainLabelsEncoded, predictedOut, trueOut, trainHighlights)
% Plots the results of a classification where the MLP ouptut space is
% three-dimensional. This corresponds to at most three classes with binary
% encoding, four classes after some sort of projection to 3-space, or a
% classification with non-binary, at most 3-dimensional, output coding.
%
% If the 'kind' is 'overlay', the class prototype vectors are subtracted
% from the whole data, so that error vectors become visualized as the
% distance from the origin.
%
% Draws in current graphics handle; create/activate a figure before call!
%
% trainHighlights = indices of training data that are of special interest..
%                   in our case it is the deliberately added outliers.
%
% TODO: This could be made more universal, but for this research it is not
%       yet required.

%if ~strcmp(kind,'separate'), error('Unknown plotkind!'); end;

showOverlay = strcmp(kind,'overlay');
showHighlights=false;
if nargin==7
    if sum(trainHighlights)>0
        showHighlights=true;
    end
end

dim =  size(prototypes,1);
nclasses = size(prototypes, 2);

if  dim ~= 3, error('This plot function is for 3d points. You ask for %d', dim); end;

predClass = classifToClosest(predictedOut, prototypes, 'indOnly');
trueClass = classifToClosest(trueOut, prototypes, 'indOnly');
trainOutClass = classifToClosest(trainOut, prototypes, 'indOnly');
trainLabelClass = classifToClosest(trainLabelsEncoded, prototypes, 'indOnly');

% If overlay was asked, do translation:
if showOverlay
    for c = 1:nclasses
        predictedOut(:,trueClass==c) = predictedOut(:,trueClass==c) ...
            - repmat(prototypes(:,c), 1, sum(trueClass==c));
        trainOut(:,trainLabelClass==c) = trainOut(:,trainLabelClass==c) ...
            - repmat(prototypes(:,c), 1, sum(trainLabelClass==c));
    end;
    prototypes = zeros(size(prototypes));
end;


allOut = [trainOut predictedOut];
allTrueLabels = [trainLabelClass trueClass];
allPredicted = [trainOutClass trainLabelClass];

% Separate classes in properly rotated 3d plot.
protoFace = 'ko';
wrongFace = 'kx';
highlightFace = 'kd';
dataPointFace = {'r.', 'b+', 'm*', 'c+', 'k+', 'c+'};
predPointFace = {'r^', 'bv', 'ms', 'c^', 'k^', 'c^'};

wrongMarkerSize = 11;
protoMarkerSize = 12;


hold on;

legstr = '';
classnames = {'c1', 'c2', 'c3'}

% Plot all data
for c = 1:nclasses
  plot3(allOut(1,allTrueLabels==c), ...
      allOut(2,allTrueLabels==c), ...
      allOut(3,allTrueLabels==c), ...
      dataPointFace{c})
  legstr{length(legstr)+1} = classnames{c};
end

% Plot predictions
for c = 1:nclasses
  plot3(predictedOut(1,predClass==c), ...
      predictedOut(2,predClass==c), ...
      predictedOut(3,predClass==c), ...
      predPointFace{c})
  if sum(predClass==c) > 0
      legstr{length(legstr)+1} = ['predict ' classnames{c}];
  end
end

% Highlight wrong *classifications* in *test data* (NOT both train and
% test):
plot3(predictedOut(1,predClass~=trueClass), ...
    predictedOut(2,predClass~=trueClass), ...
    predictedOut(3,predClass~=trueClass), ...
    wrongFace, 'markersize', wrongMarkerSize)

%legstr{length(legstr)+1} = sprintf('Wrong(%.2f%%)',100*sum(predClass~=trueClass)/numel(predClass));
legstr{length(legstr)+1} = sprintf('Wrong(%d/%d)',sum(predClass~=trueClass),numel(predClass));

% Highlight wrong *labels* in *training data*:
if showHighlights
    plot3(trainOut(1,trainHighlights), ...
        trainOut(2,trainHighlights), ...
        trainOut(3,trainHighlights), ...
        highlightFace, 'markersize', wrongMarkerSize)
    
    legstr{length(legstr)+1} = 'Mislabeled';
end


%plot3(allOut(1,allPredicted~=allTrueLabels), ...
%    allOut(2,allPredicted~=allTrueLabels), ...
%    allOut(3,allPredicted~=allTrueLabels), ...
%    wrongFace)

% Plot the prototypes
plot3(prototypes(1,:),prototypes(2,:),prototypes(3,:), protoFace, 'markersize', protoMarkerSize)
set(gca, 'DataAspectRatio',[1 1 1]);

if showOverlay
    legstr{length(legstr)+1} = 'Origin';
else
    legstr{length(legstr)+1} = 'Class Coding';
end

% Legend box as collected above:
legend(legstr);

% Turn on grids:
set(gca,'YGrid', 'on','XGrid', 'on','ZGrid', 'on');
